#!/bin/sh
#
# NzbDrone initscript
#
# Based on the mediatomb debian package.

unset USER

# PATH should only include /usr/* if it runs after the mountnfs.sh script
INSTALL_ROOT=/share/Apps/Sonarr
START_STOP_DAEMON="${INSTALL_ROOT}/bin/busybox start-stop-daemon"
PATH=/sbin:/usr/sbin:/bin:/usr/bin:${INSTALL_ROOT}/bin;export PATH
DESC="Sonarr PVR"
NAME=nzbdrone
DAEMON=${INSTALL_ROOT}/bin/mono
DAEMON_ARGS=${INSTALL_ROOT}/opt/NzbDrone/NzbDrone.exe
PIDFILE=/var/run/$NAME.pid
DEFAULT=${INSTALL_ROOT}/etc/default/${NAME}

test -x $DAEMON || exit 0

test -f $DAEMON_ARGS || exit 0

#
# Function that starts the daemon/service
#
do_start()
{
	# Return
	#   0 if daemon has been started
	#   1 if daemon was already running
	#   2 if daemon could not be started
	$START_STOP_DAEMON --start --quiet --pidfile $PIDFILE \
		-b --exec $DAEMON -- $DAEMON_ARGS \
		|| return 2
}

#
# Function that stops the daemon/service
#
do_stop()
{
	# Return
	#   0 if daemon has been stopped
	#   1 if daemon was already stopped
	#   2 if daemon could not be stopped
	#   other if a failure occurred
	$START_STOP_DAEMON --stop --quiet --retry=TERM/30/KILL/5 --pidfile $PIDFILE --name $DAEMON_ARGS
	RETVAL="$?"
	[ "$RETVAL" = 2 ] && return 2
	# Many daemons don't delete their pidfiles when they exit.
	rm -f $PIDFILE
	return "$RETVAL"
}

case "$1" in
  start)
    echo "Starting $DESC " "$NAME"
    do_start
    case "$?" in
		0|1) exit 0;;
		2) exit 1;;
	esac
  ;;
  stop)
	echo "Stopping $DESC" "$NAME"
	do_stop
	case "$?" in
		0|1) exit 0;;
		2) exit 1;;
	esac
	;;
  restart|force-reload)
	echo "Restarting $DESC" "$NAME"
	do_stop
	case "$?" in
	  0|1)
		if [ "$1" = "force-reload" ]; then
			# Rescan the collection
			DAEMON_ARGS="$DAEMON_ARGS -R"
		fi
		do_start
		case "$?" in
			0) exit 0 ;;
			1) exit 1 ;; # Old process is still running
			*) exit 1 ;; # Failed to start
		esac
		;;
	  *)
	  	# Failed to stop
		exit 1
		;;
	esac
	;;
  *)
	echo "Usage: $0 {start|stop|restart|force-reload}" >&2
	exit 3
	;;
esac

:
